==> wpewebkit_2.34.2.orig.tar.xz: wpewebkit-2.34.2/Source/WebKit/Shared/ApplePay/PaymentSetupConfigurationWebKit.h <==
/*
 * Copyright (C) 2018 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(APPLE_PAY)

#include <wtf/Forward.h>
#include <wtf/RetainPtr.h>

OBJC_CLASS PKPaymentSetupConfiguration;

namespace IPC {
class Decoder;
class Encoder;
}

namespace WebCore {
struct ApplePaySetupConfiguration;
}

namespace WebKit {

class PaymentSetupConfiguration {
public:
    PaymentSetupConfiguration() = default;
    PaymentSetupConfiguration(const WebCore::ApplePaySetupConfiguration&, const URL&);

    void encode(IPC::Encoder&) const;
    static std::optional<PaymentSetupConfiguration> decode(IPC::Decoder&);

    PKPaymentSetupConfiguration *platformConfiguration() const { return m_configuration.get(); }

private:
    explicit PaymentSetupConfiguration(RetainPtr<PKPaymentSetupConfiguration>&&);

    RetainPtr<PKPaymentSetupConfiguration> m_configuration;
};

} // namespace WebKit

#endif // ENABLE(APPLE_PAY)

==> wpewebkit_2.46.5.orig.tar.xz: wpewebkit-2.46.5/Source/WebKit/Shared/ApplePay/PaymentSetupConfigurationWebKit.h <==
/*
 * Copyright (C) 2018 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(APPLE_PAY)

#include <WebCore/ApplePaySetupConfiguration.h>
#include <wtf/RetainPtr.h>
#include <wtf/URL.h>

OBJC_CLASS PKPaymentSetupConfiguration;

namespace WebKit {

class PaymentSetupConfiguration {
public:
    PaymentSetupConfiguration(const WebCore::ApplePaySetupConfiguration&, const URL&);

    RetainPtr<PKPaymentSetupConfiguration> platformConfiguration() const;

    const WebCore::ApplePaySetupConfiguration& configuration() const { return m_configuration; }
    const URL& url() const { return m_url; }

private:
    WebCore::ApplePaySetupConfiguration m_configuration;
    URL m_url;
};

} // namespace WebKit

#endif // ENABLE(APPLE_PAY)
